Supvisors status

| Node
--- | ---
Name: | --
IP Address: | --

| Processor
--- | ---
Physical / Logical cores: | --
Processor frequency: | --

| Memory
--- | ---
Physical: | --

###### Processor Statistics (%)

# | Latest | Mean | Slope/P | StdDev
--- | --- | --- | --- | ---
-- | -- | -- | -- | --

###### Memory Statistics (%)

mem | Latest | Mean | Slope/P | StdDev
--- | --- | --- | --- | ---
-- | -- | -- | --

###### Network I/O Statistics (kbit/s)

Interface | Rx/Tx | Latest | Mean | Slope/P | StdDev
--- | --- | --- | --- | --- | ---
-- | -- | -- | -- | -- | --

Disk usage
Disk I/O

###### Disk I/O Statistics (kbit/s)

Device | R/W | Latest | Mean | Slope/P | StdDev
--- | --- | --- | --- | --- | ---
-- | -- | -- | -- | -- | --

Disk usage
Disk I/O

###### Disk Usage Statistics (%)

Partition | Latest | Mean | Slope/P | StdDev
--- | --- | --- | --- | ---
-- | -- | -- | -- | --

on